@@ -2,6 +2,9 @@
 
 import psutil
 from psutil._common import bytes2human
+from twisted.internet import threads
+from twisted.internet.defer import inlineCallbacks
+
 from .base import SysInfoBase
 
 
@@ -16,8 +19,12 @@ class MemoryInfo(SysInfoBase):
             'available': self._available
         }
 
+    @inlineCallbacks
     def _capacity(self):
-        return bytes2human(psutil.virtual_memory().total)
+        result = yield threads.deferToThread(psutil.virtual_memory)
+        return bytes2human(result.total)
 
+    @inlineCallbacks
     def _available(self):
-        return bytes2human(psutil.virtual_memory().available)
+        result = yield threads.deferToThread(psutil.virtual_memory)
+        return bytes2human(result.available)
